#!/bin/bash

# $Id: minimap.sh,v 1.11 2004/08/18 21:52:07 cyhiggin Exp $
# This is what I use to generate the maps on my website
# (see http://www.randomly.org/projects/mapper).

# Placed in the public domain.
# Oliver Jowett <oliver@randomly.org>   28/10/2002

source=/usr/network/familiar/camelot/patches/TOA_mapper
bindir=/home/cynthia/programming/mapper/mapper-base
IMDIR=/home/cynthia/nathrach/src/maps
WEBPREFIX=/home/cynthia/nathrach/src/maps

# THISDIR=`pwd`

OVERVIEW_INI=mg_overview.ini
NOBOUNDS_OV_INI=mg_overview_nob.ini
LAVA_OV_INI=mg_overview_lava.ini
DETAIL_INI=mg_detail.ini
NOBOUNDS_DETAIL_INI=mg_detail_nob.ini
LAVA_DETAIL_INI=mg_detail_lava.ini

# functions used a lot

# get_zone_list(region)
get_zone_list() {
    ZONES0=`python ${bindir}/zonelist.py -gamepath $source -region $1 -simple`
}

# zone_lists(classic_region, si_region, housing_region, toa_start, which, frontier_region)
zone_lists() {
    case $5 in
	all)
	    get_zone_list $1 && ZCLASSIC=$ZONES0
	    get_zone_list $2 && ZSI=$ZONES0
	    get_zone_list $3 && ZHOUSING=$ZONES0
	    get_zone_list $4 && ZTOA=$ZONES0
	    get_zone_list $6 && ZFRONTIER=$ZONES0
	    ZONES="$ZCLASSIC $ZHOUSING $ZTOA $ZSI $ZFRONTIER" 
	;;
	classic)
	    get_zone_list $1 && ZCLASSIC=$ZONES0
	    ZONES=$ZCLASSIC 
	;;
	si)
	    get_zone_list $2 && ZSI=$ZONES0
	    get_zone_list $4 && ZTOA=$ZONES0
	    ZONES="$ZTOA $ZSI"
	;;
	house)
	    get_zone_list $3 && ZHOUSING=$ZONES0
	    ZONES=$ZHOUSING
	;;
	frontier)
	    get_zone_list 234 && ZBG1=$ZONES0
	    get_zone_list 235 && ZBG2=$ZONES0
	    get_zone_list 236 && ZBG3=$ZONES0
	    get_zone_list 237 && ZBG4=$ZONES0
	    get_zone_list 238 && ZBG5=$ZONES0
	    get_zone_list 239 && ZBG6=$ZONES0
	    get_zone_list 240 && ZBG7=$ZONES0
	    get_zone_list 241 && ZBG8=$ZONES0
	    get_zone_list 242 && ZBG9=$ZONES0
	    
	    get_zone_list $6 && ZFRONTIER=$ZONES0
	    ZONES="$ZBG1 $ZBG2 $ZBG3 $ZBG4 $ZBG5 $ZBG6 $ZBG7 $ZBG8 $ZBG9 $ZFRONTIER" 
	    ;;

	*)
	    echo "Usage: $0 {alb|mid|hib|toa|frontier} {all|classic|si|house} [ov-only]"
	    exit 1
    esac
}

# create_map_pieces(z, detail_ini, overview_ini)
create_map_pieces() {
    # draw detail map
    if [ $OVERVIEW == "0" ]; then
	python ${bindir}/mapper.py -settings $2 -gamepath $source \
	    -scale 512 -zone $1 -out work/map${1}.png
	pngtopnm work/map${1}.png | pnmtojpeg --optimize >out/map${1}.jpg
    fi
  
    # draw_overview_piece
    python ${bindir}/mapper.py -settings $3 -gamepath $source \
      -scale 512 -zone $1 -out work/map${1}_o.png
}

# create_overview(basename, region, scale)
create_overview(){
    python ${bindir}/glue.py -gamepath $source -out work/${1}.png \
	-scale $3 -fontpath $font -template work/map%03d_o.png -region $2 \
	>out/${1}.imagemap
    pngtopnm work/${1}.png | pnmquant -floyd 256 | \
	pnmtopng -transparent black >out/${1}.png
}

# barf on errors
#set -e

# move to work directory
cd ${bindir}

if [ $3F == "ov-onlyF" ]; then
    OVERVIEW=1
else
    OVERVIEW=0
fi

case $1 in
    alb)
	WEBDIR=${WEBPREFIX}/albion
        # get list of zones
	zone_lists 1 51 2 70 $2 163
	;;
    mid)
	WEBDIR=${WEBPREFIX}/midgard
        # get list of Mid zones
	zone_lists 100 151 102 71 $2 163
	;;
    hib)
	WEBDIR=${WEBPREFIX}/hibernia
        # get list of Hib zones
	zone_lists 200 181 202 72 $2 163
	;;
    toa)
	WEBDIR=${WEBPREFIX}/atlantis
        # get TOA zones 
	get_zone_list 73 && ZONES=$ZONES0
	;;
    frontier)
	WEBDIR=${WEBPREFIX}/frontier
        # get Frontier zones 
	zone_lists 0 0 0 0 "frontier" 163
	;;

    *)
	echo "Usage: $0 {alb|mid|hib|toa|frontier} {all|classic|si|house} [ov-only]"
	exit 1
	;;
esac

# make work and output directories
mkdir -p ${WEBDIR} work out

# create maps w/borders
for z in $ZONES
do
  # known lava zones
  if [[ $z == "104" || $z == "084" || $z == "085" ]] ; then
      echo "Creating maps of lava zone $z..."
      create_map_pieces $z $LAVA_DETAIL_INI $LAVA_OV_INI
  # zones with known buggy boundaries
  elif [[ $z == "052" || $z == "184" || $z == "152" || $z == "170"
 || $z == "234" || $z == "235" || $z == "236" || $z == "237" || $z == "238"
 || $z == "239" || $z = "240" || $z = "241" || $2 == "house" ]] ; then
      echo "Creating maps of no-bounds zone $z..."
      create_map_pieces $z $NOBOUNDS_DETAIL_INI $NOBOUNDS_OV_INI
  # normal zones
  else
      echo "Creating maps of zone $z..."
      create_map_pieces $z $DETAIL_INI $OVERVIEW_INI
  fi
done

case $1 in
    alb)
	case $2 in
	    all)
	      # create alb overview maps
		font=./6x12-ISO8859-1.pil
		create_overview "albion_classic" 1 10
		
		font=./timR24-ISO8859-1.pil
		create_overview "albion_si" 51 15
		create_overview "albion_housing" 2 20
		;;
	    classic)
	      # create alb overview maps
		font=./6x12-ISO8859-1.pil
		create_overview "albion_classic" 1 10
		;;
	    si)
		font=./timR24-ISO8859-1.pil
		create_overview "albion_si" 51 15
		;;
	    house)
		font=./timR24-ISO8859-1.pil
		create_overview "albion_housing" 2 20
		;;
	esac
	;;
    mid)
	case $2 in
	    all)
		# create mid overview maps
		font=./6x12-ISO8859-1.pil
		create_overview "midgard_classic" 100 10
		font=./timR24-ISO8859-1.pil
		create_overview "midgard_si" 151 15
		create_overview "midgard_housing" 102 20
		;;
	    classic)
		font=./6x12-ISO8859-1.pil
		create_overview "midgard_classic" 100 10
		;;
	    si)
		font=./timR24-ISO8859-1.pil
		create_overview "midgard_si" 151 15
		;;
	    house)
		font=./timR24-ISO8859-1.pil
		create_overview "midgard_housing" 102 20
		;;
	esac
	;;
    hib)
	case $2 in
	    all)
                # create hib overview maps
		font=./6x12-ISO8859-1.pil
		create_overview "hibernia_classic" 200 10
		
		font=./timR24-ISO8859-1.pil
		create_overview "hibernia_si" 181 15
		create_overview "hibernia_housing" 202 20
		;;
	    classic)
		font=./6x12-ISO8859-1.pil
		create_overview "hibernia_classic" 200 10
		;;
	    si)
		font=./timR24-ISO8859-1.pil
		create_overview "hibernia_si" 181 15
		;;
	    house)
		font=./timR24-ISO8859-1.pil
		create_overview "hibernia_housing" 202 20
		;;
	esac
	;;
    toa)
	font=./6x12-ISO8859-1.pil
	create_overview "atlantis" 73 15
	;;
    frontier)
	font=./6x12-ISO8859-1.pil
#		font=./timR24-ISO8859-1.pil
	create_overview "frontier" 163 10
	;;
    
    *)
	echo "How the heck did we get here?"
	exit 1
	;;
esac

mv -v out/*.imagemap ${IMDIR}
cp -v out/* ${WEBDIR}
rm out/* work/*
# Changelog:
#    $Log: minimap.sh,v $
#    Revision 1.11  2004/08/18 21:52:07  cyhiggin
#    split WEBDIR up into WEBPREFIX & path so can easily change where maps go.
#
#    Revision 1.10  2004/06/17 19:05:37  cyhiggin
#    2.3.1 catch-up
#
#    Revision 1.9  2004/06/08 19:58:07  cyhiggin
#    updates for 2.3, including New Frontiers support
#
#    Revision 1.8  2004/04/15 21:25:03  cyhiggin
#    Added 2nd arg for classic/housing/si/all, so don't have to do whole realm when just want housing.
#
#    Revision 1.7  2004/04/05 12:14:29  cyhiggin
#    Updated ini files; added new tree objects as per updates to MapperGUI
#
#    Revision 1.6  2004/03/28 20:07:28  cyhiggin
#    added mv of imagemaps to nathrach src directory
#
#    Revision 1.5  2004/03/28 14:19:02  cyhiggin
#    updated filenames to match Rath Nathrach site requirements
#
#    Revision 1.4  2004/03/27 16:04:43  cyhiggin
#    changed webdirs to new Rath Nathrach map directories
#
#    Revision 1.3  2004/03/16 19:34:27  cyhiggin
#    Made exceptions for the 3 SI zones with buggy borders.
#
#    Revision 1.2  2004/03/14 18:58:53  cyhiggin
#    updated bindir
#
#
## end minimap.sh ##
